# local_graph - Module Enrichment

**File:** `./src/autodoc/local_graph.py`
**Last Updated:** 2025-06-27T16:13:59.051582
**Total Entities:** 7
**Functions:** 1
**Classes:** 1

## Module Entities

*No enrichments available yet. Run `autodoc enrich` to add detailed descriptions.*

### Functions

#### `main` (line 243)
> Run local graph visualization

### Classes

#### `LocalCodeGraph` (line 21)
> Create code graphs directly from autodoc entities without Neo4j
